summaryrefslogtreecommitdiff
path: root/libmysql
diff options
context:
space:
mode:
authorklemens <ka7@github.com>2017-02-26 16:49:47 +0100
committerSergey Vojtovich <svoj@mariadb.org>2017-03-07 13:38:06 +0400
commit7be541f281225aae8e04bff4210b67688be080bc (patch)
treef6ba5f7862669d13b4c425d44baa7528f42da1d3 /libmysql
parente823023e4bb48b0db9ee91477076fc20db704769 (diff)
downloadmariadb-git-7be541f281225aae8e04bff4210b67688be080bc.tar.gz
spelling fixes
Diffstat (limited to 'libmysql')
-rw-r--r--libmysql/CMakeLists.txt2
-rw-r--r--libmysql/libmysql.c20
2 files changed, 11 insertions, 11 deletions
diff --git a/libmysql/CMakeLists.txt b/libmysql/CMakeLists.txt
index 417f91c7879..8e60d267521 100644
--- a/libmysql/CMakeLists.txt
+++ b/libmysql/CMakeLists.txt
@@ -476,7 +476,7 @@ IF(NOT DISABLE_SHARED)
EXPORTS ${CLIENT_API_FUNCTIONS} ${CLIENT_API_5_1_EXTRA} ${CLIENT_API_5_5_EXTRA}
COMPONENT SharedLibraries)
IF(UNIX)
- # libtool compatability
+ # libtool compatibility
IF(CMAKE_SYSTEM_NAME MATCHES "FreeBSD" OR APPLE)
SET(OS_SHARED_LIB_VERSION "${SHARED_LIB_MAJOR_VERSION}")
ELSEIF(CMAKE_SYSTEM_NAME MATCHES "HP-UX")
diff --git a/libmysql/libmysql.c b/libmysql/libmysql.c
index 4d7d8a380a7..477314b0af3 100644
--- a/libmysql/libmysql.c
+++ b/libmysql/libmysql.c
@@ -195,7 +195,7 @@ int STDCALL mysql_server_init(int argc __attribute__((unused)),
the library.
To make things simpler when used with windows dll's (which calls this
- function automaticly), it's safe to call this function multiple times.
+ function automatically), it's safe to call this function multiple times.
*/
@@ -220,7 +220,7 @@ void STDCALL mysql_server_end()
}
#ifdef NOT_NEEDED
/*
- The following is not needed as if the program explicitely called
+ The following is not needed as if the program explicitly called
my_init() then we can assume it will also call my_end().
The reason to not also do it here is in that case we can't get
statistics from my_end() to debug log.
@@ -605,7 +605,7 @@ static int default_local_infile_init(void **ptr, const char *filename,
default_local_infile_read()
ptr Points to handle allocated by _init
buf Read data here
- buf_len Ammount of data to read
+ buf_len Amount of data to read
RETURN
> 0 number of bytes read
@@ -660,7 +660,7 @@ static void default_local_infile_end(void *ptr)
ptr Points to handle allocated by _init
May be NULL if _init failed!
error_msg Store error text here
- error_msg_len Max lenght of error_msg
+ error_msg_len Max length of error_msg
RETURN
error message number
@@ -1270,7 +1270,7 @@ static int stmt_read_row_no_result_set(MYSQL_STMT *stmt, unsigned char **row);
static void stmt_update_metadata(MYSQL_STMT *stmt, MYSQL_ROWS *data);
static my_bool setup_one_fetch_function(MYSQL_BIND *, MYSQL_FIELD *field);
/* Auxilary function used to reset statement handle. */
#define RESET_SERVER_SIDE 1
#define RESET_LONG_DATA 2
@@ -1814,7 +1814,7 @@ static void update_stmt_fields(MYSQL_STMT *stmt)
RETURN
NULL statement contains no result set or out of memory.
- In the latter case you can retreive error message
+ In the latter case you can retrieve error message
with mysql_stmt_error.
MYSQL_RES a result set with no rows
*/
@@ -1852,7 +1852,7 @@ mysql_stmt_result_metadata(MYSQL_STMT *stmt)
Returns parameter columns meta information in the form of
result set.
- SYNOPSYS
+ SYNOPSIS
mysql_stmt_param_metadata()
stmt statement handle
@@ -1901,7 +1901,7 @@ static void store_param_type(unsigned char **pos, MYSQL_BIND *param)
param MySQL bind param
DESCRIPTION
- These funtions are invoked from mysql_stmt_execute() by
+ These functions are invoked from mysql_stmt_execute() by
MYSQL_BIND::store_param_func pointer. This pointer is set once per
many executions in mysql_stmt_bind_param(). The caller must ensure
that network buffer have enough capacity to store parameter
@@ -2078,7 +2078,7 @@ static my_bool store_param(MYSQL_STMT *stmt, MYSQL_BIND *param)
/*
- Auxilary function to send COM_STMT_EXECUTE packet to server and read reply.
+ Auxiliary function to send COM_STMT_EXECUTE packet to server and read reply.
Used from cli_stmt_execute, which is in turn used by mysql_stmt_execute.
*/
@@ -4466,7 +4466,7 @@ int STDCALL mysql_stmt_store_result(MYSQL_STMT *stmt)
if (stmt->update_max_length && !stmt->bind_result_done)
{
/*
- We must initalize the bind structure to be able to calculate
+ We must initialize the bind structure to be able to calculate
max_length
*/
MYSQL_BIND *my_bind, *end;
@@ -1270,7 +1270,7 @@ static int stmt_read_row_no_result_set(MYSQL_STMT *stmt, unsigned char **row);
static void stmt_update_metadata(MYSQL_STMT *stmt, MYSQL_ROWS *data);
static my_bool setup_one_fetch_function(MYSQL_BIND *, MYSQL_FIELD *field);
-/* Auxilary function used to reset statement handle. */
+/* Auxiliary function used to reset statement handle. */
#define RESET_SERVER_SIDE 1
#define RESET_LONG_DATA 2